@@ -117,12 +117,24 @@ module.exports = function (app) {
     fscan.scan(app.nylon.work_dir + route_dir, ".routes.js", true, function (err, routes) {
         loadRouter(app, "/api", app.nylon.work_dir, route_dir, routes, function (err, app) {
 
-            app.get('/*', prpl.makeHandler('./public', {
-                builds: [
-                    { name: '.', browserCapabilities: ['es2015', 'push'] },
-                    { name: '.' },
-                ],
-            }));
+            var evn=process.env.NYLON_WEB_TYPE || 'development';
+            var evn_build=process.env.NYLON_WEB_BUILD_NAME || 'default';
+            if(evn.toLowerCase()=="production"){
+                app.get('/*', prpl.makeHandler('./public/build/'+evn_build, {
+                    builds: [
+                        { name: '.', browserCapabilities: ['es2015', 'push'] },
+                        { name: '.' },
+                    ],
+                }));
+            }else{
+                app.get('/*', prpl.makeHandler('./public', {
+                    builds: [
+                        { name: '.', browserCapabilities: ['es2015', 'push'] },
+                        { name: '.' },
+                    ],
+                }));
+            }
+            
 
         });
     });
